@@ -979,7 +979,7 @@ class KmsClient(AbstractClient):
 
 
     def GetPublicKey(self, request):
-        """This API is used to get the information of the public key that is encrypted with the asymmetric cryptographic algorithm and of which the `KeyUsage` is `ASYMMETRIC_DECRYPT_RSA_2048` or `ASYMMETRIC_DECRYPT_SM2`. This public key can be used to encrypt data locally, and the data encrypted with it can only be decrypted with the corresponding private key through KMS. The public key can only be obtained from the asymmetric key in `Enabled` state.
+        """This API is used to get the public key of an asymmetric KMS key (which must be enabled). With the public key, you can encrypt messages and verify signatures.
 
         :param request: Request instance for GetPublicKey.
         :type request: :class:`tencentcloud.kms.v20190118.models.GetPublicKeyRequest`
@@ -1007,7 +1007,7 @@ class KmsClient(AbstractClient):
 
 
     def GetRegions(self, request):
-        """This API is used to obtain the list of supported regions.
+        """This API is used to return all regions support KMS service.
 
         :param request: Request instance for GetRegions.
         :type request: :class:`tencentcloud.kms.v20190118.models.GetRegionsRequest`
@@ -1261,7 +1261,7 @@ class KmsClient(AbstractClient):
 
     def SignByAsymmetricKey(self, request):
         """This API is used to generate a signature with an asymmetric key.
-        Note: only the keys with `KeyUsage= ASYMMETRIC_SIGN_VERIFY_SM2` can be used for signature generation.
+        Note that only when KeyUsage is `ASYMMETRIC_SIGN_VERIFY_${ALGORITHM}` (e.g., `ASYMMETRIC_SIGN_VERIFY_SM2` and `ASYMMETRIC_SIGN_VERIFY_ECC`), the key can be used for signing.
 
         :param request: Request instance for SignByAsymmetricKey.
         :type request: :class:`tencentcloud.kms.v20190118.models.SignByAsymmetricKeyRequest`
