@@ -203,7 +203,7 @@ INVALIDPARAMETERVALUE_APMCONFIGINSTANCEID = 'InvalidParameterValue.ApmConfigInst
 # ApmConfigRegion input error
 INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
 
-# 
+# The value of Args is incorrect.
 INVALIDPARAMETERVALUE_ARGS = 'InvalidParameterValue.Args'
 
 # The parameter for async retry configuration of the function is invalid.
@@ -218,9 +218,15 @@ INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParamete
 # The value of `cfs` configuration item does not meet the specification.
 INVALIDPARAMETERVALUE_CFSPARAMETERERROR = 'InvalidParameterValue.CfsParameterError'
 
+# The CFS parameter format does not conform to the specification.
+INVALIDPARAMETERVALUE_CFSSTRUCTIONERROR = 'InvalidParameterValue.CfsStructionError'
+
 # Ckafka error.
 INVALIDPARAMETERVALUE_CKAFKA = 'InvalidParameterValue.Ckafka'
 
+# 
+INVALIDPARAMETERVALUE_CLIENTCONTEXT = 'InvalidParameterValue.ClientContext'
+
 # Cls error.
 INVALIDPARAMETERVALUE_CLS = 'InvalidParameterValue.Cls'
 
@@ -239,7 +245,7 @@ INVALIDPARAMETERVALUE_CODESECRET = 'InvalidParameterValue.CodeSecret'
 # CodeSource error.
 INVALIDPARAMETERVALUE_CODESOURCE = 'InvalidParameterValue.CodeSource'
 
-# 
+# The value of Command[Entrypoint] is incorrect.
 INVALIDPARAMETERVALUE_COMMAND = 'InvalidParameterValue.Command'
 
 # Incorrect `CompatibleRuntimes` parameter.
@@ -275,7 +281,7 @@ INVALIDPARAMETERVALUE_DEFAULTNAMESPACE = 'InvalidParameterValue.DefaultNamespace
 # Description error.
 INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'
 
-# 
+# The configuration of the environment variable DNS[OS_NAMESERVER] is incorrect.
 INVALIDPARAMETERVALUE_DNSINFO = 'InvalidParameterValue.DnsInfo'
 
 # EipConfig parameter error.
@@ -296,6 +302,9 @@ INVALIDPARAMETERVALUE_ENVIRONMENTSYSTEMPROTECT = 'InvalidParameterValue.Environm
 # Filters parameter error.
 INVALIDPARAMETERVALUE_FILTERS = 'InvalidParameterValue.Filters'
 
+# The value of `FunctionName` is incorrect. See https://tencentcs.com/5jXKFnBW
+INVALIDPARAMETERVALUE_FUNCTION = 'InvalidParameterValue.Function'
+
 # The function does not exist.
 INVALIDPARAMETERVALUE_FUNCTIONNAME = 'InvalidParameterValue.FunctionName'
 
@@ -323,7 +332,7 @@ INVALIDPARAMETERVALUE_HANDLER = 'InvalidParameterValue.Handler'
 # IdleTimeOut input parameter error
 INVALIDPARAMETERVALUE_IDLETIMEOUT = 'InvalidParameterValue.IdleTimeOut'
 
-# 
+# The input of imageUri is incorrect.
 INVALIDPARAMETERVALUE_IMAGEURI = 'InvalidParameterValue.ImageUri'
 
 # Invalid InlineZipFile.
@@ -359,6 +368,12 @@ INVALIDPARAMETERVALUE_NAMESPACE = 'InvalidParameterValue.Namespace'
 # Incorrect Namespace. A namespace contains up to 30 characters of letters, digits, hyphens (-), and underscores (_).
 INVALIDPARAMETERVALUE_NAMESPACEINVALID = 'InvalidParameterValue.NamespaceInvalid'
 
+# 
+INVALIDPARAMETERVALUE_NODESPEC = 'InvalidParameterValue.NodeSpec'
+
+# 
+INVALIDPARAMETERVALUE_NODETYPE = 'InvalidParameterValue.NodeType'
+
 # Invalid offset.
 INVALIDPARAMETERVALUE_OFFSET = 'InvalidParameterValue.Offset'
 
@@ -392,7 +407,7 @@ INVALIDPARAMETERVALUE_PUBLICNETCONFIG = 'InvalidParameterValue.PublicNetConfig'
 # Unsupported function version.
 INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'
 
-# 
+# The value Enterprise Edition image ID [RegistryId] is incorrect.
 INVALIDPARAMETERVALUE_REGISTRYID = 'InvalidParameterValue.RegistryId'
 
 # Invalid RetCode
@@ -416,6 +431,9 @@ INVALIDPARAMETERVALUE_SERVICENAME = 'InvalidParameterValue.ServiceName'
 # The value of `Stamp` does not meet the specification. Please fix it and try again.
 INVALIDPARAMETERVALUE_STAMP = 'InvalidParameterValue.Stamp'
 
+# The start time is incorrect.
+INVALIDPARAMETERVALUE_STARTTIME = 'InvalidParameterValue.StartTime'
+
 # You need to specify both the start time and the end time.
 INVALIDPARAMETERVALUE_STARTTIMEORENDTIME = 'InvalidParameterValue.StartTimeOrEndTime'
 
@@ -431,6 +449,9 @@ INVALIDPARAMETERVALUE_TEMPCOSOBJECTNAME = 'InvalidParameterValue.TempCosObjectNa
 # The value of `TraceEnable` is invalid. Please modify and try again.
 INVALIDPARAMETERVALUE_TRACEENABLE = 'InvalidParameterValue.TraceEnable'
 
+# 
+INVALIDPARAMETERVALUE_TRACKINGTARGET = 'InvalidParameterValue.TrackingTarget'
+
 # TriggerCronConfig input parameter error
 INVALIDPARAMETERVALUE_TRIGGERCRONCONFIG = 'InvalidParameterValue.TriggerCronConfig'
 
@@ -590,6 +611,9 @@ RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 # Unable to find the specified mount point under the specified CFS
 RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
 
+# 
+RESOURCENOTFOUND_CFSSTATUSERROR = 'ResourceNotFound.CfsStatusError'
+
 # VPCs of the CFS instance and the SCF function are different.
 RESOURCENOTFOUND_CFSVPCNOTMATCH = 'ResourceNotFound.CfsVpcNotMatch'
 
@@ -638,6 +662,9 @@ RESOURCENOTFOUND_QUALIFIER = 'ResourceNotFound.Qualifier'
 # The role does not exist.
 RESOURCENOTFOUND_ROLE = 'ResourceNotFound.Role'
 
+# 
+RESOURCENOTFOUND_ROLECHECK = 'ResourceNotFound.RoleCheck'
+
 # Timer does not exist.
 RESOURCENOTFOUND_TIMER = 'ResourceNotFound.Timer'
 
@@ -704,8 +731,14 @@ UNSUPPORTEDOPERATION_CDN = 'UnsupportedOperation.Cdn'
 # Cos operation is not supported.
 UNSUPPORTEDOPERATION_COS = 'UnsupportedOperation.Cos'
 
+# 
+UNSUPPORTEDOPERATION_EIPFIXED = 'UnsupportedOperation.EipFixed'
+
 # This region is not supported.
 UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 
 # Trigger operation is not supported.
 UNSUPPORTEDOPERATION_TRIGGER = 'UnsupportedOperation.Trigger'
+
+# 
+UNSUPPORTEDOPERATION_VPCCONFIG = 'UnsupportedOperation.VpcConfig'
