@@ -77,6 +77,9 @@ INTERNALERROR_CVMNOTFOUND = 'InternalError.CvmNotFound'
 # Some of the CVMs cannot be found
 INTERNALERROR_CVMNUMBERNOTMATCH = 'InternalError.CvmNumberNotMatch'
 
+# Exceptional CVM status.
+INTERNALERROR_CVMSTATUS = 'InternalError.CvmStatus'
+
 # DB error.
 INTERNALERROR_DB = 'InternalError.Db'
 
